@@ -32,7 +32,7 @@ static unsigned leafs_gathered_size; /* space allocated for array above,
 					only needed for "invariant" */
 static unsigned leafs_gathered_next; /* next available space in leafs_gathered
 					for the description of a leaf */
-Tree *all_trees = NULL; /* list of all trees */
+static Tree *all_trees = NULL; /* list of all trees */
 
 static GTA *gta_global; /* for invariant only */
 
