@@ -23,23 +23,24 @@
 #include "../Mem/mem.h"
 #include "gta.h"
 
-SsId s, lSs, rSs; /* current, left and right state spaces; s is the
-		     state space that has been split, lSs and rSs, the
-		     successors of s, are the candidates for further
-		     splitting */
-GTA *orig, *res; /* original and resulting automata */
+static SsId s, lSs, rSs; /* current, left and right state spaces; s is the
+			    state space that has been split, lSs and rSs, the
+			    successors of s, are the candidates for further
+			    splitting */
+static GTA *orig, *res; /* original and resulting automata */
 
-unsigned **block; /* block[s][i] is the block number (discriminator)
-		     of state i in state space s; block numbers are
-		     consecutive, starting at 0 */
+static unsigned **block; /* block[s][i] is the block number (discriminator)
+			    of state i in state space s; block numbers are
+			    consecutive, starting at 0 */
 
-unsigned *numBlocks; /* numBlocks[s] is the size of the partition for
-			state space s, i.e.  highest block number + 1 */
+static unsigned *numBlocks; /* numBlocks[s] is the size of the partition for
+			       state space s, i.e.  highest block number + 1 */
 
-bdd_ptr *matrix, *transposed; /* normal and transposed behaviour matrix, 
-				 note: contains bdd_ptrs not bdd_handles 
-				 to obtain fewer cache misses during compare */
-enum Candidate {
+static bdd_ptr *matrix, *transposed; /* normal and transposed behaviour matrix, 
+					note: contains bdd_ptrs not bdd_handles 
+					to obtain fewer cache misses during compare */
+
+static enum Candidate {
   cNEVER, 
   cHASBEEN, 
   cYES
@@ -56,17 +57,17 @@ enum Candidate {
 
 /* sorting */
 
-bdd_ptr **sorted; /* invariant: sorted[i][j] == qm[original[i]*maxSize + j]
-		     in fact, sorted[i] == &qm[original[i]*maxSize] */
-unsigned *original; /* original[i] = the original number of a row
-		       in sorted order */
-bdd_ptr *qm; /* matrix to be sorted, for storage allocation
-		purposes, row length is assume to be maxSize; actual
-		rowlength is given by qcols; also maxSize rows are
-		allocated */
-unsigned qcols, maxSize; /* used and allocated number of columns
-				in matrix qm */
-unsigned *qb; /* qb[i] = block[s][original[i]] */
+static bdd_ptr **sorted; /* invariant: sorted[i][j] == qm[original[i]*maxSize + j]
+			    in fact, sorted[i] == &qm[original[i]*maxSize] */
+static unsigned *original; /* original[i] = the original number of a row
+			      in sorted order */
+static bdd_ptr *qm; /* matrix to be sorted, for storage allocation
+		       purposes, row length is assume to be maxSize; actual
+		       rowlength is given by qcols; also maxSize rows are
+		       allocated */
+static unsigned qcols, maxSize; /* used and allocated number of columns
+				   in matrix qm */
+static unsigned *qb; /* qb[i] = block[s][original[i]] */
 
 int compare(unsigned i, unsigned j)
 {
