@@ -27,11 +27,11 @@
 #define STATUS_TO_BOOL(s) ((s == -1) ? 0 : 1)
 #define BOOL_TO_STATUS(s) ((s == 0) ? -1 : 1)
 
-BehaviourMatrix *b; /* extendable matrices */ 
-PairArray *pairs; /* map states to pairs of states */
-PairHashTable *inverse; /* inverses for 'pairs' */
-GTA *aa1, *aa2, *res; /* automata */
-SsId s, lSs, rSs; /* current, left and right state spaces */
+static BehaviourMatrix *b; /* extendable matrices */ 
+static PairArray *pairs; /* map states to pairs of states */
+static PairHashTable *inverse; /* inverses for 'pairs' */
+static GTA *aa1, *aa2, *res; /* automata */
+static SsId s, lSs, rSs; /* current, left and right state spaces */
 
 static unsigned fn_pair(unsigned p, unsigned q)
 {
