@@ -25,17 +25,17 @@
 #include "projset.h" /* StateSet */
 #include "subsets.h" /* Subsets */
 
-GTA *orig, *res; /* original and result GTA */
-SsId s, lSs, rSs; /* current, left and right state spaces */
+static GTA *orig, *res; /* original and result GTA */
+static SsId s, lSs, rSs; /* current, left and right state spaces */
 
-StateSet *unproc, *initial; /* for quotient */
+static StateSet *unproc, *initial; /* for quotient */
 
-BehaviourMatrix *b; /* extendable behaviour matrix */
-Subsets *sets; /* subset containers */
+static BehaviourMatrix *b; /* extendable behaviour matrix */
+static Subsets *sets; /* subset containers */
 
-State *init; /* initial states */
-int *final; /* final status sequence */
-unsigned finalAllocated; /* allocated size of 'final' */
+static State *init; /* initial states */
+static int *final; /* final status sequence */
+static unsigned finalAllocated; /* allocated size of 'final' */
 
 /* quotient auxiliary functions */
 
