@@ -23,12 +23,12 @@
 #include "gta.h"
 #include "dyn.h"
 
-GTA *orig, *res; /* original and result GTA */
-BehaviourMatrix *resbeh;
-State **newNumber; /* maps old state numbers to new */
-State **oldNumber; /* inverse of newNumber */
-State *nextNewNumber; /* used size of newNumber */
-SsId s, lSs, rSs; /* current, left and right state spaces */
+static GTA *orig, *res; /* original and result GTA */
+static BehaviourMatrix *resbeh;
+static State **newNumber; /* maps old state numbers to new */
+static State **oldNumber; /* inverse of newNumber */
+static State *nextNewNumber; /* used size of newNumber */
+static SsId s, lSs, rSs; /* current, left and right state spaces */
 
 /* auxiliary functions */
 
